@@ -5,6 +5,8 @@
 */ 
 
 /* includes */
+#include <sys/types.h>
+#include <string.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <time.h>
@@ -16,7 +18,7 @@ extern int s;
 /* send tamagotchi list to client */
 void list()
 {
-	char buf[BUFLEN], tmp[16];
+	char buf[BUFLEN], tmp[BUFLEN];
 	unsigned int ctr, num=0;
 	FILE *ptr;
 
